@@ -8,7 +8,7 @@
  * contain plain-text bodies, HTML bodies, attachments, inline
  * images and specific headers.
  *
- * Compatible with PHP version 5 and 7
+ * Compatible with PHP version 5, 7 and 8
  *
  * LICENSE: This LICENSE is in the BSD license style.
  * Copyright (c) 2002-2003, Richard Heyes <richard@phpguru.org>
@@ -792,7 +792,7 @@ class Mail_mime
         // Write the rest of the message into file
         $res = $this->get($params, $filename);
 
-        return $res ?: true;
+        return $res ? $res : true;
     }
 
     /**
@@ -837,7 +837,7 @@ class Mail_mime
             @ini_set('magic_quotes_runtime', $magic_quotes);
         }
 
-        return $res ?: true;
+        return $res ? $res : true;
     }
 
     /**
@@ -987,12 +987,12 @@ class Mail_mime
         $alternatives_count = $html + $calendar + $has_text;
 
         if ($alternatives_count > 1) {
-            $alt_part = $this->addAlternativePart($parent_part ?: $mixed_params);
+            $alt_part = $this->addAlternativePart($parent_part ? $parent_part : $mixed_params);
         } else {
             $alt_part = null;
         }
 
-        $dest_part = $alt_part ?: $parent_part;
+        $dest_part = $alt_part ? $alt_part : $parent_part;
         $part = null;
 
         if ($has_text) {
@@ -1007,7 +1007,7 @@ class Mail_mime
             $part = $this->addCalendarPart($dest_part);
         }
 
-        return $dest_part ?: $part;
+        return $dest_part ? $dest_part : $part;
     }
 
     /**
@@ -1368,7 +1368,7 @@ class Mail_mime
             break;
 
         case $html && $html_images && !$attachments && !$has_alternatives:
-            $headers['Content-Type'] = 'multiplart/related';
+            $headers['Content-Type'] = 'multipart/related';
             break;
 
         case $calendar && !$attachments && !$has_alternatives:
@@ -1382,8 +1382,11 @@ class Mail_mime
         case $attachments:
             $headers['Content-Type'] = 'multipart/mixed';
             break;
+        }
 
-        default:
+        // Note: This is outside of the above switch construct to workaround
+        // opcache bug: https://bugzilla.opensuse.org/show_bug.cgi?id=1166235
+        if (empty($headers)) {
             return $headers;
         }
 
